@@ -1,6 +1,6 @@
 # See LICENSE.md file in project root directory
 
-def getConfigByLabel(config:list[dict], label:str):
+def getConfigByLabel(config:'list[dict]', label:str):
     for c in config:
         if "label" not in c or "value" not in c:
             continue
@@ -9,7 +9,7 @@ def getConfigByLabel(config:list[dict], label:str):
     return None
 
 
-def getFieldByKey(fields:list[dict], key:str):
+def getFieldByKey(fields:'list[dict]', key:str):
     for f in fields:
         if "key" not in f or "value" not in f:
             continue
@@ -18,7 +18,7 @@ def getFieldByKey(fields:list[dict], key:str):
     return None
 
 
-def getFieldsByKey(fields:list[dict], key:str):
+def getFieldsByKey(fields:'list[dict]', key:str):
     ret = []
     for f in fields:
         if "key" not in f or "value" not in f:
@@ -28,7 +28,7 @@ def getFieldsByKey(fields:list[dict], key:str):
     return ret
 
 
-def getFieldIndex(fields:list[dict], key:str, value:str):
+def getFieldIndex(fields:'list[dict]', key:str, value:str):
     for i,f in enumerate(fields):
         if "key" not in f or "value" not in f:
             continue
